@@ -2176,11 +2176,15 @@ parseindex:
 		{
 		    if ((int)sl->lab_port == idx)
 		    {
-			TxError("Port index %d is already used by port %s.\n"
-				"Use command \"port index %d\" to force "
-				"equivalence after defining the port.\n",
-				idx, sl->lab_text, idx);
-			return;
+			/* This is only an error if port name doesn't match */
+			if (strcmp(sl->lab_text, lab->lab_text))
+			{
+			    TxError("Port index %d is already used by port %s.\n"
+					"Use command \"port index %d\" to force "
+					"equivalence after defining the port.\n",
+					idx, sl->lab_text, idx);
+			    return;
+			}
 		    }
 		}
 	    }
@@ -2431,14 +2435,14 @@ printPropertiesFunc(
     }
     else
     {
-	keyvalue = (char *)mallocMagic(strlen(name) + strlen((char *)value) + 2);
-	sprintf(keyvalue, "%s %s", name, (char *)value);
+	keyvalue = (char *)mallocMagic(strlen(name) + strlen((const char *)value) + 2);
+	sprintf(keyvalue, "%s %s", name, (const char *)value);
     }
     Tcl_AppendElement(magicinterp, keyvalue);
     freeMagic(keyvalue);
 
 #else
-    TxPrintf("%s = %s\n", name, value);
+    TxPrintf("%s = %s\n", name, (const char *)value);
 #endif
 
     return 0;	/* keep the search alive */
